==> bitly_shortener-1.0.0.tar.gz: bitly_shortener/src/Form/BitlyShortenerSettingsForm.php <==
<?php

/**
 * @file
 * Contents \Drupal\bitly_shortener\Form\BitlyShortenerSettingsForm
 */

namespace Drupal\bitly_shortener\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 *	Class BitlyShortenerSettingsForm
 *	@package Drupal\bitly_shortener\Form
 */
class BitlyShortenerSettingsForm extends ConfigFormBase {

	/**
	 *	{@inheritdoc}
	 */
	public function getFormId() {
		return 'bitly_shortener_settings_form';
	}

	/**
	 *	{@inheritdoc}
	 */
	protected function getEditableConfigNames() {
		return ['bitly_shortener.settings'];
	}

	/**
	 *	{@inheritdoc}
	 */
	public function buildForm(array $form, FormStateInterface $form_state) {
		$bitly_url = \Drupal::service('bitly_shortener')->shortener('https://www.drupal.org/');
		\Drupal::messenger()->addMessage('Bitly Shortener Status: '. $bitly_url);

		$settings = $this->config('bitly_shortener.settings');

		// General message time form settings.
		$form['bitly_shortener_settings'] = array(
			'#type' => 'details',
			'#title' => $this->t('Bitly Shortener'),
			'#open' => TRUE,
		);

		$form['bitly_shortener_settings']['bitly_shortener_enable'] = array(
	  	'#type' => 'checkbox',
  		'#title' => t('Bitly Shortener Enable'),
  		'#default_value' => $settings->get('bitly_shortener_enable')
    );

		$form['bitly_shortener_settings']['bitly_shortener_token'] = array(
			'#type' => 'textfield',
			'#title' => $this->t('Access Token'),
			'#description' => $this->t('Generate access token. <a href="https://app.bitly.com/settings/api" target="_blank">https://app.bitly.com/settings/api/</a>'),
			'#default_value' => $settings->get('bitly_shortener_token'),
			'#states' => array(
				'required' => array(
					':input[name="bitly_shortener_enable"]' => array('checked' => TRUE),
				),
			),
		);

		return parent::buildForm($form, $form_state);
	}

	/**
	 *	{@inheritdoc}
	 */
	public function validateForm(array &$form, FormStateInterface $form_state) {
		$values = $form_state->getValues();
    if(!preg_match('/^[a-zA-Z0-9]{40}+$/', $values['bitly_shortener_token'])) {
      $form_state->setErrorByName('bitly_shortener_token', t('Invalid bitly access token.'));
    }
	}

	/**
	 *	{@inheritdoc}
	 */
	public function submitForm(array &$form, FormStateInterface $form_state) {
		$this->config('bitly_shortener.settings')
			->set('bitly_shortener_token', $form_state->getValue('bitly_shortener_token'))
			->set('bitly_shortener_enable', $form_state->getValue('bitly_shortener_enable'))
			->save();
			\Drupal::messenger()->addMessage(t('Bitly Shortener Configration Saved.'));
	}
}

==> bitly_shortener-1.0.1.tar.gz: bitly_shortener/src/Form/BitlyShortenerSettingsForm.php <==
<?php

namespace Drupal\bitly_shortener\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 *	Class BitlyShortenerSettingsForm
 *	@package Drupal\bitly_shortener\Form
 */
class BitlyShortenerSettingsForm extends ConfigFormBase {
	use StringTranslationTrait;

	/**
	 *	{@inheritdoc}
	 */
	public function getFormId() {
		return 'bitly_shortener_settings_form';
	}

	/**
	 *	{@inheritdoc}
	 */
	protected function getEditableConfigNames() {
		return ['bitly_shortener.settings'];
	}

	/**
	 *	{@inheritdoc}
	 */
	public function buildForm(array $form, FormStateInterface $form_state) {

		$bitly_url = \Drupal::service('bitly_shortener')->shortener('https://www.drupal.org/');

		\Drupal::messenger()->addMessage('Bitly Shortener Status: '. $bitly_url);

		$settings = $this->config('bitly_shortener.settings');

		// General message time form settings.
		$form['bitly_shortener_settings'] = [
			'#type' => 'details',
			'#title' => $this->t('Bitly Shortener'),
			'#open' => TRUE,
		];

		$form['bitly_shortener_settings']['bitly_shortener_enable'] = [
	  	'#type' => 'checkbox',
  		'#title' => $this->t('Bitly Shortener Enable'),
  		'#default_value' => $settings->get('bitly_shortener_enable')
		];

		$form['bitly_shortener_settings']['bitly_shortener_token'] = [
			'#type' => 'textfield',
			'#title' => $this->t('Access Token'),
			'#description' => $this->t('Generate access token. <a href="https://app.bitly.com/settings/api" target="_blank">https://app.bitly.com/settings/api/</a>'),
			'#default_value' => $settings->get('bitly_shortener_token'),
			'#states' => [
				'required' => [
					':input[name="bitly_shortener_enable"]' => ['checked' => TRUE],
				],
				'visible' => [
					':input[name="bitly_shortener_enable"]' => ['checked' => TRUE],
				]
			],
		];

		return parent::buildForm($form, $form_state);
	}

	/**
	 *	{@inheritdoc}
	 */
	public function validateForm(array &$form, FormStateInterface $form_state) {
		$values = $form_state->getValues();
		if(!preg_match('/^[a-zA-Z0-9]{40}+$/', $values['bitly_shortener_token'])) {
			$form_state->setErrorByName('bitly_shortener_token', $this->t('Invalid bitly access token.'));
		}
	}

	/**
	 *	{@inheritdoc}
	 */
	public function submitForm(array &$form, FormStateInterface $form_state) {
		$this->config('bitly_shortener.settings')
			->set('bitly_shortener_token', $form_state->getValue('bitly_shortener_token'))
			->set('bitly_shortener_enable', $form_state->getValue('bitly_shortener_enable'))
			->save();
		\Drupal::messenger()->addMessage($this->t('Bitly Shortener Configration Saved.'));
	}
}
